pub struct MockOrganizationSponsorshipsApi {
OrganizationSponsorshipsApi_expectations: MockOrganizationSponsorshipsApi_OrganizationSponsorshipsApi,
}Fields
OrganizationSponsorshipsApi_expectations: MockOrganizationSponsorshipsApi_OrganizationSponsorshipsApiImplementations
Sourceimpl MockOrganizationSponsorshipsApi
impl MockOrganizationSponsorshipsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationSponsorshipsApi
impl MockOrganizationSponsorshipsApi
Sourcepub fn expect_admin_initiated_revoke_sponsorship(&mut self) -> &mut Expectation
pub fn expect_admin_initiated_revoke_sponsorship(&mut self) -> &mut Expectation
Create an Expectation for mocking the admin_initiated_revoke_sponsorship method
Sourcepub fn expect_create_sponsorship(&mut self) -> &mut Expectation
pub fn expect_create_sponsorship(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_sponsorship method
Sourcepub fn expect_get_sponsored_organizations(&mut self) -> &mut Expectation
pub fn expect_get_sponsored_organizations(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_sponsored_organizations method
Sourcepub fn expect_get_sync_status(&mut self) -> &mut Expectation
pub fn expect_get_sync_status(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_sync_status method
Sourcepub fn expect_pre_validate_sponsorship_token(&mut self) -> &mut Expectation
pub fn expect_pre_validate_sponsorship_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the pre_validate_sponsorship_token method
Sourcepub fn expect_redeem_sponsorship(&mut self) -> &mut Expectation
pub fn expect_redeem_sponsorship(&mut self) -> &mut Expectation
Create an Expectation for mocking the redeem_sponsorship method
Sourcepub fn expect_remove_sponsorship(&mut self) -> &mut Expectation
pub fn expect_remove_sponsorship(&mut self) -> &mut Expectation
Create an Expectation for mocking the remove_sponsorship method
Sourcepub fn expect_resend_sponsorship_offer(&mut self) -> &mut Expectation
pub fn expect_resend_sponsorship_offer(&mut self) -> &mut Expectation
Create an Expectation for mocking the resend_sponsorship_offer method
Sourcepub fn expect_revoke_sponsorship(&mut self) -> &mut Expectation
pub fn expect_revoke_sponsorship(&mut self) -> &mut Expectation
Create an Expectation for mocking the revoke_sponsorship method
Sourcepub fn expect_sync(&mut self) -> &mut Expectation
pub fn expect_sync(&mut self) -> &mut Expectation
Create an Expectation for mocking the sync method